#
# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2005 Red Hat, Inc.
# All rights reserved.
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation version
# 2.1 of the License.
#                                                                                  
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#                                                                                  
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
# END COPYRIGHT BLOCK
#
# This file defines dependencies for components and 
# tells how to satisfy thoes dependencies

# For internal components, we use ftp_puller_new.pl
# We should consider using wget or something like that
# in the future.

FTP_PULL = $(PERL) $(RELTOOLSPATH)/ftp_puller_new.pl -logdir $(ABS_ROOT_PARENT) 

BUILD_MODE = ext

ifndef NSPR_SOURCE_ROOT
NSPR_IMPORT = $(COMPONENTS_DIR)/nspr20/$(NSPR_RELDATE)/$(FULL_RTL_OBJDIR)
NSPR_DEP = $(NSPR_LIBPATH)/libnspr4.$(LIB_SUFFIX)

ifndef NSPR_PULL_METHOD
NSPR_PULL_METHOD = $(COMPONENT_PULL_METHOD)
endif

$(NSPR_DEP): $(RELTOOLS) $(NSCP_DISTDIR_FULL_RTL)
ifdef COMPONENT_DEPS
	$(FTP_PULL) -method $(NSPR_PULL_METHOD) \
		-objdir $(NSPR_BUILD_DIR) -componentdir $(NSPR_IMPORT) \
		-files lib,include
endif
	-@if [ ! -f $@ ] ; \
	then echo "Error: could not get component NSPR file $@" ; \
	fi
endif # NSPR_SOURCE_ROOT

ifndef SECURITY_SOURCE_ROOT
SECURITY_IMPORT = $(COMPONENTS_DIR)/nss/$(SECURITY_RELDATE)/$(FULL_RTL_OBJDIR)
ifeq ($(ARCH), WINNT)
  SECURITY_DEP = $(SECURITY_LIBPATH)/ssl3.$(DLL_SUFFIX)
else
  SECURITY_DEP = $(SECURITY_LIBPATH)/libssl3.$(DLL_SUFFIX)
endif

ifdef VSFTPD_HACK
SECURITY_FILES=lib
else
SECURITY_FILES=lib,include
endif

ifndef SECURITY_PULL_METHOD
SECURITY_PULL_METHOD = $(COMPONENT_PULL_METHOD)
endif

$(SECURITY_DEP): $(RELTOOLS) $(NSCP_DISTDIR_FULL_RTL)
ifdef COMPONENT_DEPS
	$(FTP_PULL) -method $(SECURITY_PULL_METHOD) \
		-objdir $(SECURITY_BUILD_DIR) -componentdir $(SECURITY_IMPORT) \
		-files $(SECURITY_FILES)
ifdef VSFTPD_HACK
# work around vsftpd -L problem
	$(FTP_PULL) -method $(SECURITY_PULL_METHOD) \
		-objdir $(SECURITY_BUILD_DIR) -componentdir $(COMPONENTS_DIR)/nss/$(SECURITY_RELDATE) \
		-files include
endif
endif # COMPONENT_DEPS
	-@if [ ! -f $@ ] ; \
	then echo "Error: could not get component NSS file $@" ; \
	fi
endif # SECURITY_SOURCE_ROOT

ifndef LDAPSDK_SOURCE_ROOT
ifndef LDAP_VERSION
  LDAP_VERSION = $(LDAP_RELDATE)
endif
ifndef LDAP_SBC
#LDAP_SBC = $(COMPONENTS_DIR_DEV)
LDAP_SBC = $(COMPONENTS_DIR)
endif
LDAPOBJDIR = $(FULL_RTL_OBJDIR)
# LDAP does not have PTH version, so here is the hack which treat non PTH
# version as PTH version
ifeq ($(USE_PTHREADS), 1)
  LDAP_RELEASE = $(LDAP_SBC)/$(LDAPCOMP_DIR)/$(LDAP_VERSION)/$(NSOBJDIR_NAME)
else
  LDAP_RELEASE = $(LDAP_SBC)/$(LDAPCOMP_DIR)/$(LDAP_VERSION)/$(LDAPOBJDIR)
endif
ifeq ($(ARCH), WINNT)
  LDAPSDK_DEP = $(LDAPSDK_LIBPATH)/nsldap32v$(LDAP_SUF).$(DLL_SUFFIX)
  LDAPSDK_PULL_LIBS = lib/nsldapssl32v$(LDAP_SUF).$(LIB_SUFFIX),lib/nsldapssl32v$(LDAP_SUF).$(LDAP_DLL_SUFFIX),lib/nsldap32v$(LDAP_SUF).$(LIB_SUFFIX),lib/nsldap32v$(LDAP_SUF).$(LDAP_DLL_SUFFIX),lib/nsldappr32v$(LDAP_SUF).$(LIB_SUFFIX),lib/nsldappr32v$(LDAP_SUF).$(LDAP_DLL_SUFFIX)
else
  LDAPSDK_DEP = $(LDAPSDK_LIBPATH)/libldap$(LDAP_SUF).$(DLL_SUFFIX)
  LDAPSDK_PULL_LIBS = lib/libssldap$(LDAP_SUF)$(LDAP_DLL_PRESUF).$(LDAP_DLL_SUFFIX),lib/libldap$(LDAP_SUF)$(LDAP_DLL_PRESUF).$(LDAP_DLL_SUFFIX),lib/libprldap$(LDAP_SUF)$(LDAP_DLL_PRESUF).$(LDAP_DLL_SUFFIX)
endif

ifndef LDAPSDK_PULL_METHOD
LDAPSDK_PULL_METHOD = $(COMPONENT_PULL_METHOD)
endif

$(LDAPSDK_DEP): $(RELTOOLS) $(NSCP_DISTDIR_FULL_RTL)
ifdef COMPONENT_DEPS
	mkdir -p $(LDAP_LIBPATH)
	$(FTP_PULL) -method $(LDAPSDK_PULL_METHOD) \
		-objdir $(LDAP_ROOT) -componentdir $(LDAP_RELEASE) \
		-files include,$(LDAPSDK_PULL_LIBS),bin
endif
	-@if [ ! -f $@ ] ; \
	then echo "Error: could not get component LDAPSDK file $@" ; \
	fi
endif # LDAPSDK_SOURCE_ROOT

ifndef ICU_SOURCE_ROOT
#ICU_RELEASE = $(COMPONENTS_DIR)/libicu/$(ICU_VERSDIR)/$(ICU_RELDATE)/$(NSOBJDIR_NAME)
ICU_RELEASE = $(INT_DIR)/libicu/$(ICU_VERSDIR)/$(ICU_RELDATE)/$(NSOBJDIR_NAME)
ICU_DEP = $(ICU_INCPATH)/unicode/ucol.h
ifndef ICU_PULL_METHOD
ICU_PULL_METHOD = $(COMPONENT_PULL_METHOD)
endif

$(ICU_DEP): $(RELTOOLS) $(NSCP_DISTDIR_FULL_RTL)
ifdef COMPONENT_DEPS
	$(FTP_PULL) -method $(ICU_PULL_METHOD) \
		-objdir $(ICU_BUILD_DIR) -componentdir $(ICU_RELEASE) \
		-files lib,include,bin
endif
	-@if [ ! -f $@ ] ; \
	then echo "Error: could not get component ICU file $@" ; \
	fi
endif # ICU_SOURCE_ROOT

######## END OF OPEN SOURCE COMPONENTS ######################

